@@ -35,11 +35,11 @@
 
 /* {{{ _pylibmc.client implementation */
 /* {{{ Type methods */
-static HandMC_Client *HandMC_ClientType_new(PyTypeObject *type,
+static PylibMC_Client *PylibMC_ClientType_new(PyTypeObject *type,
         PyObject *args, PyObject *kwds) {
-    HandMC_Client *self;
+    PylibMC_Client *self;
 
-    self = (HandMC_Client *)type->tp_alloc(type, 0);
+    self = (PylibMC_Client *)type->tp_alloc(type, 0);
     if (self != NULL) {
         self->mc = memcached_create(NULL);
     }
@@ -47,12 +47,12 @@ static HandMC_Client *HandMC_ClientType_new(PyTypeObject *type,
     return self;
 }
 
-static void HandMC_ClientType_dealloc(HandMC_Client *self) {
+static void PylibMC_ClientType_dealloc(PylibMC_Client *self) {
     memcached_free(self->mc);
 }
 /* }}} */
 
-static int HandMC_Client_init(HandMC_Client *self, PyObject *args,
+static int PylibMC_Client_init(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
     PyObject *srv_list, *srv_list_it;
 
@@ -79,24 +79,24 @@ static int HandMC_Client_init(HandMC_Client *self, PyObject *args,
 
                     rc = memcached_server_push(self->mc, list);
                     if (rc != MEMCACHED_SUCCESS) {
-                        HandMC_ErrFromMemcached(self,
+                        PylibMC_ErrFromMemcached(self,
                                 "memcached_server_push", rc);
                     }
                     free(list);
                 } else {
-                    PyErr_SetString(HandMCExc_MemcachedError,
+                    PyErr_SetString(PylibMCExc_MemcachedError,
                             "memcached_servers_parse returned NULL");
                 }
             } else if (PyArg_ParseTuple(c_srv, "Bs|H",
                         &stype, &hostname, &port)) {
                 switch (stype) {
-                    case HANDMC_SERVER_TCP:
+                    case PYLIBMC_SERVER_TCP:
                         memcached_server_add(self->mc, hostname, port);
                         break;
-                    case HANDMC_SERVER_UDP:
+                    case PYLIBMC_SERVER_UDP:
                         memcached_server_add_udp(self->mc, hostname, port);
                         break;
-                    case HANDMC_SERVER_UNIX:
+                    case PYLIBMC_SERVER_UNIX:
                         if (port) {
                             PyErr_SetString(PyExc_ValueError,
                                     "can't set port on unix sockets");
@@ -118,37 +118,37 @@ static int HandMC_Client_init(HandMC_Client *self, PyObject *args,
     return PyErr_Occurred() ? -1 : 0;
 }
 
-static PyObject *_HandMC_parse_memcached_value(char *value, size_t size,
+static PyObject *_PylibMC_parse_memcached_value(char *value, size_t size,
         uint32_t flags) {
     PyObject *retval;
 
     retval = NULL;
     switch (flags) {
-        case HANDMC_FLAG_PICKLE:
-            retval = _HandMC_Unpickle(value, size);
+        case PYLIBMC_FLAG_PICKLE:
+            retval = _PylibMC_Unpickle(value, size);
             break;
-        case HANDMC_FLAG_INTEGER:
-        case HANDMC_FLAG_LONG:
+        case PYLIBMC_FLAG_INTEGER:
+        case PYLIBMC_FLAG_LONG:
             retval = PyInt_FromString(value, NULL, 10);
             break;
-        case HANDMC_FLAG_NONE:
+        case PYLIBMC_FLAG_NONE:
             retval = PyString_FromStringAndSize(value, (Py_ssize_t)size);
             break;
         default:
-            PyErr_Format(HandMCExc_MemcachedError,
+            PyErr_Format(PylibMCExc_MemcachedError,
                     "unknown memcached key flags %u", flags);
     }
 
     return retval;
 }
 
-static PyObject *HandMC_Client_get(HandMC_Client *self, PyObject *arg) {
+static PyObject *PylibMC_Client_get(PylibMC_Client *self, PyObject *arg) {
     char *mc_val;
     size_t val_size;
     uint32_t flags;
     memcached_return error;
 
-    if (!_HandMC_CheckKey(arg)) {
+    if (!_PylibMC_CheckKey(arg)) {
         return NULL;
     } else if (!PySequence_Length(arg) ) {
         /* Others do this, so... */
@@ -159,7 +159,7 @@ static PyObject *HandMC_Client_get(HandMC_Client *self, PyObject *arg) {
             PyString_AS_STRING(arg), PyString_GET_SIZE(arg),
             &val_size, &flags, &error);
     if (mc_val != NULL) {
-        PyObject *r = _HandMC_parse_memcached_value(mc_val, val_size, flags);
+        PyObject *r = _PylibMC_parse_memcached_value(mc_val, val_size, flags);
         free(mc_val);
         return r;
     }
@@ -170,11 +170,11 @@ static PyObject *HandMC_Client_get(HandMC_Client *self, PyObject *arg) {
         Py_RETURN_NONE;
     }
 
-    return HandMC_ErrFromMemcached(self, "memcached_get", error);
+    return PylibMC_ErrFromMemcached(self, "memcached_get", error);
 }
 
 /* {{{ Set commands (set, replace, add, prepend, append) */
-static PyObject *_HandMC_RunSetCommand(HandMC_Client *self, _HandMC_SetCommand f,
+static PyObject *_PylibMC_RunSetCommand(PylibMC_Client *self, _PylibMC_SetCommand f,
         char *fname, PyObject *args, PyObject *kwds) {
     char *key;
     size_t key_len;
@@ -189,23 +189,23 @@ static PyObject *_HandMC_RunSetCommand(HandMC_Client *self, _HandMC_SetCommand f
         PyObject *store_val = NULL;
         uint32_t store_flags = 0;
 
-        Py_INCREF(val);
-        if (!_HandMC_CheckKey(PyString_FromString(key))) {
-            /* Hum di dum. */
+        if (!_PylibMC_CheckKeyStringAndSize(key, key_len)) {
+            /* Let store_val be NULL, thus triggering an error. */
         } else if (PyString_Check(val)) {
             store_val = val;
         } else if (PyInt_Check(val)) {
-            store_flags |= HANDMC_FLAG_INTEGER;
+            store_flags |= PYLIBMC_FLAG_INTEGER;
             store_val = PyObject_Str(val);
         } else if (PyLong_Check(val)) {
-            store_flags |= HANDMC_FLAG_LONG;
+            store_flags |= PYLIBMC_FLAG_LONG;
             store_val = PyObject_Str(val);
         } else {
-            store_flags |= HANDMC_FLAG_PICKLE;
-            store_val = _HandMC_Pickle(val);
+            Py_INCREF(val);
+            store_flags |= PYLIBMC_FLAG_PICKLE;
+            store_val = _PylibMC_Pickle(val);
+            Py_DECREF(val);
         }
 
-        Py_INCREF(store_val);
         if (store_val != NULL) {
             memcached_return rc;
             const char *raw_val;
@@ -213,6 +213,8 @@ static PyObject *_HandMC_RunSetCommand(HandMC_Client *self, _HandMC_SetCommand f
             
             raw_val = PyString_AS_STRING(store_val);
             raw_val_len = PyString_GET_SIZE(store_val);
+            Py_DECREF(store_val);
+
             rc = f(self->mc, key, key_len, raw_val, raw_val_len, time,
                     store_flags);
             switch (rc) {
@@ -226,51 +228,49 @@ static PyObject *_HandMC_RunSetCommand(HandMC_Client *self, _HandMC_SetCommand f
                     retval = Py_False;
                     break;
                 default:
-                    HandMC_ErrFromMemcached(self, fname, rc);
+                    PylibMC_ErrFromMemcached(self, fname, rc);
             }
         }
-        Py_DECREF(store_val);
-        Py_DECREF(val);
     }
 
     Py_XINCREF(retval);
     return retval;
 }
 
-/* These all just call _HandMC_RunSetCommand with the appropriate arguments. 
+/* These all just call _PylibMC_RunSetCommand with the appropriate arguments. 
  * In other words: bulk. */
-static PyObject *HandMC_Client_set(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_set(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
-    return _HandMC_RunSetCommand(
+    return _PylibMC_RunSetCommand(
             self, memcached_set, "memcached_set", args, kwds);
 }
 
-static PyObject *HandMC_Client_replace(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_replace(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
-    return _HandMC_RunSetCommand(
+    return _PylibMC_RunSetCommand(
             self, memcached_replace, "memcached_replace", args, kwds);
 }
 
-static PyObject *HandMC_Client_add(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_add(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
-    return _HandMC_RunSetCommand(
+    return _PylibMC_RunSetCommand(
             self, memcached_add, "memcached_add", args, kwds);
 }
 
-static PyObject *HandMC_Client_prepend(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_prepend(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
-    return _HandMC_RunSetCommand(
+    return _PylibMC_RunSetCommand(
             self, memcached_prepend, "memcached_prepend", args, kwds);
 }
 
-static PyObject *HandMC_Client_append(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_append(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
-    return _HandMC_RunSetCommand(
+    return _PylibMC_RunSetCommand(
             self, memcached_append, "memcached_append", args, kwds);
 }
 /* }}} */
 
-static PyObject *HandMC_Client_delete(HandMC_Client *self, PyObject *args) {
+static PyObject *PylibMC_Client_delete(PylibMC_Client *self, PyObject *args) {
     PyObject *retval;
     char *key;
     size_t key_len;
@@ -280,7 +280,7 @@ static PyObject *HandMC_Client_delete(HandMC_Client *self, PyObject *args) {
     retval = NULL;
     time = 0;
     if (PyArg_ParseTuple(args, "s#|I", &key, &key_len, &time)
-            && _HandMC_CheckKey(PyString_FromStringAndSize(key, key_len))) {
+            && _PylibMC_CheckKeyStringAndSize(key, key_len)) {
         switch (rc = memcached_delete(self->mc, key, key_len, time)) {
             case MEMCACHED_SUCCESS:
                 retval = Py_True;
@@ -291,7 +291,7 @@ static PyObject *HandMC_Client_delete(HandMC_Client *self, PyObject *args) {
                 retval = Py_False;
                 break;
             default:
-                retval = HandMC_ErrFromMemcached(self, "memcached_delete", rc);
+                retval = PylibMC_ErrFromMemcached(self, "memcached_delete", rc);
         }
     }
 
@@ -300,7 +300,7 @@ static PyObject *HandMC_Client_delete(HandMC_Client *self, PyObject *args) {
 }
 
 /* {{{ Increment & decrement */
-static PyObject *_HandMC_IncDec(HandMC_Client *self, uint8_t dir, 
+static PyObject *_PylibMC_IncDec(PylibMC_Client *self, uint8_t dir, 
         PyObject *args) {
     PyObject *retval;
     char *key;
@@ -311,29 +311,28 @@ static PyObject *_HandMC_IncDec(HandMC_Client *self, uint8_t dir,
     retval = NULL;
     delta = 1;
     if (PyArg_ParseTuple(args, "s#|I", &key, &key_len, &delta)
-            && _HandMC_CheckKey(PyString_FromStringAndSize(key, key_len))) {
+            && _PylibMC_CheckKeyStringAndSize(key, key_len)) {
         memcached_return (*incdec)(memcached_st *, const char *, size_t,
                 unsigned int, uint64_t *);
-        incdec = (dir == HANDMC_INC) ? memcached_increment
+        incdec = (dir == PYLIBMC_INC) ? memcached_increment
                                      : memcached_decrement;
         incdec(self->mc, key, key_len, delta, &result);
         retval = PyLong_FromUnsignedLong((unsigned long)result);
     }
 
-    Py_XINCREF(retval);
     return retval;
 }
 
-static PyObject *HandMC_Client_incr(HandMC_Client *self, PyObject *args) {
-    return _HandMC_IncDec(self, HANDMC_INC, args);
+static PyObject *PylibMC_Client_incr(PylibMC_Client *self, PyObject *args) {
+    return _PylibMC_IncDec(self, PYLIBMC_INC, args);
 }
 
-static PyObject *HandMC_Client_decr(HandMC_Client *self, PyObject *args) {
-    return _HandMC_IncDec(self, HANDMC_DEC, args);
+static PyObject *PylibMC_Client_decr(PylibMC_Client *self, PyObject *args) {
+    return _PylibMC_IncDec(self, PYLIBMC_DEC, args);
 }
 /* }}} */
 
-static PyObject *HandMC_Client_get_multi(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_get_multi(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
     PyObject *key_seq, **key_objs, *retval = NULL;
     char **keys, *prefix = NULL;
@@ -412,7 +411,7 @@ static PyObject *HandMC_Client_get_multi(HandMC_Client *self, PyObject *args,
                     /* Do nothing at all. :-) */
                 } else if (rc != MEMCACHED_SUCCESS) {
                     Py_DECREF(retval);
-                    retval = HandMC_ErrFromMemcached(
+                    retval = PylibMC_ErrFromMemcached(
                             self, "memcached_fetch", rc);
                 } else {
                     PyObject *val;
@@ -420,7 +419,7 @@ static PyObject *HandMC_Client_get_multi(HandMC_Client *self, PyObject *args,
                     /* This is safe because libmemcached's max key length
                      * includes space for a NUL-byte. */
                     curr_key[curr_key_len] = 0;
-                    val = _HandMC_parse_memcached_value(
+                    val = _PylibMC_parse_memcached_value(
                             curr_val, curr_val_len, curr_flags);
                     PyDict_SetItemString(retval, curr_key + prefix_len, val);
                     Py_DECREF(val);
@@ -434,7 +433,7 @@ static PyObject *HandMC_Client_get_multi(HandMC_Client *self, PyObject *args,
                 memcached_quit(self->mc);
             }
         } else {
-            retval = HandMC_ErrFromMemcached(self, "memcached_mget", rc);
+            retval = PylibMC_ErrFromMemcached(self, "memcached_mget", rc);
         }
 
         free(key_lens);
@@ -453,12 +452,12 @@ static PyObject *HandMC_Client_get_multi(HandMC_Client *self, PyObject *args,
  * Run func over every item in value, building arguments of:
  *     *(item + extra_args)
  */
-static PyObject *_HandMC_DoMulti(PyObject *values, PyObject *func,
+static PyObject *_PylibMC_DoMulti(PyObject *values, PyObject *func,
         PyObject *prefix, PyObject *extra_args) {
     PyObject *retval = PyList_New(0);
     PyObject *iter = NULL;
     PyObject *item = NULL;
-    int is_dict = PyDict_Check(values);
+    int is_mapping = PyMapping_Check(values);
 
     if (retval == NULL)
         goto error;
@@ -468,7 +467,6 @@ static PyObject *_HandMC_DoMulti(PyObject *values, PyObject *func,
 
     while ((item = PyIter_Next(iter)) != NULL) {
         PyObject *args_f = NULL;
-        PyObject *value = NULL;
         PyObject *args = NULL;
         PyObject *key = NULL;
         PyObject *ro = NULL;
@@ -476,19 +474,22 @@ static PyObject *_HandMC_DoMulti(PyObject *values, PyObject *func,
         /* Calculate key. */
         if (prefix == NULL || prefix == Py_None) {
             /* We now have two owned references to item. */
-            Py_INCREF(item);
             key = item;
+            Py_INCREF(key);
         } else {
             key = PySequence_Concat(prefix, item);
         }
-        if (key == NULL)
+        if (key == NULL || !_PylibMC_CheckKey(key))
             goto iter_error;
 
         /* Calculate args. */
-        if (is_dict) {
-            if ((value = PyDict_GetItem(values, item)) == NULL) {
+        if (is_mapping) {
+            PyObject *value;
+            char *key_str = PyString_AS_STRING(item);
+
+            if ((value = PyMapping_GetItemString(values, key_str)) == NULL)
                 goto iter_error;
-            }
+
             args = PyTuple_Pack(2, key, value);
         } else {
             args = PyTuple_Pack(1, key);
@@ -510,13 +511,15 @@ static PyObject *_HandMC_DoMulti(PyObject *values, PyObject *func,
         /* This is actually safe even if True got deleted because we're
          * only comparing addresses. */
         Py_XDECREF(ro);
-        if (ro != Py_True) {
+        if (ro == NULL) {
+            goto iter_error;
+        } else if (ro != Py_True) {
             if (PyList_Append(retval, item) != 0)
                 goto iter_error;
         }
         Py_DECREF(args_f);
         Py_DECREF(args);
-        Py_XDECREF(key);
+        Py_DECREF(key);
         Py_DECREF(item);
         continue;
 iter_error:
@@ -535,7 +538,7 @@ error:
     return NULL;
 }
 
-static PyObject *HandMC_Client_set_multi(HandMC_Client *self, PyObject *args,
+static PyObject *PylibMC_Client_set_multi(PylibMC_Client *self, PyObject *args,
         PyObject *kwds) {
     PyObject *prefix = NULL;
     PyObject *time = NULL;
@@ -554,11 +557,11 @@ static PyObject *HandMC_Client_set_multi(HandMC_Client *self, PyObject *args,
         return NULL;
 
     if (time == NULL) {
-        retval = _HandMC_DoMulti(map, set, prefix, NULL);
+        retval = _PylibMC_DoMulti(map, set, prefix, NULL);
     } else {
         if ((call_args = PyTuple_Pack(1, time)) == NULL)
             goto error;
-        retval = _HandMC_DoMulti(map, set, prefix, call_args);
+        retval = _PylibMC_DoMulti(map, set, prefix, call_args);
         Py_DECREF(call_args);
     }
     Py_DECREF(set);
@@ -569,7 +572,7 @@ error:
     return NULL;
 }
 
-static PyObject *HandMC_Client_delete_multi(HandMC_Client *self,
+static PyObject *PylibMC_Client_delete_multi(PylibMC_Client *self,
         PyObject *args, PyObject *kwds) {
     PyObject *prefix = NULL;
     PyObject *time = NULL;
@@ -588,11 +591,11 @@ static PyObject *HandMC_Client_delete_multi(HandMC_Client *self,
         return NULL;
 
     if (time == NULL) {
-        retval = _HandMC_DoMulti(keys, delete, prefix, NULL);
+        retval = _PylibMC_DoMulti(keys, delete, prefix, NULL);
     } else {
         if ((call_args = PyTuple_Pack(1, time)) == NULL)
             goto error;
-        retval = _HandMC_DoMulti(keys, delete, prefix, call_args);
+        retval = _PylibMC_DoMulti(keys, delete, prefix, call_args);
         Py_DECREF(call_args);
     }
     Py_DECREF(delete);
@@ -603,11 +606,11 @@ error:
     return NULL;
 }
 
-static PyObject *HandMC_Client_get_behaviors(HandMC_Client *self) {
+static PyObject *PylibMC_Client_get_behaviors(PylibMC_Client *self) {
     PyObject *retval = PyDict_New();
-    HandMC_Behavior *b;
+    PylibMC_Behavior *b;
 
-    for (b = HandMC_behaviors; b->name != NULL; b++) {
+    for (b = PylibMC_behaviors; b->name != NULL; b++) {
         uint64_t bval = memcached_behavior_get(self->mc, b->flag);
         PyObject *x = PyInt_FromLong(bval);
 
@@ -624,11 +627,11 @@ error:
     return NULL;
 }
 
-static PyObject *HandMC_Client_set_behaviors(HandMC_Client *self,
+static PyObject *PylibMC_Client_set_behaviors(PylibMC_Client *self,
         PyObject *behaviors) {
-    HandMC_Behavior *b;
+    PylibMC_Behavior *b;
 
-    for (b = HandMC_behaviors; b->name != NULL; b++) {
+    for (b = PylibMC_behaviors; b->name != NULL; b++) {
         if (PyMapping_HasKeyString(behaviors, b->name)) {
             PyObject *v = PyMapping_GetItemString(behaviors, b->name);
             memcached_return r;
@@ -642,7 +645,7 @@ static PyObject *HandMC_Client_set_behaviors(HandMC_Client *self,
             r = memcached_behavior_set(self->mc, b->flag, PyInt_AS_LONG(v));
             Py_DECREF(v);
             if (r != MEMCACHED_SUCCESS) {
-                PyErr_Format(HandMCExc_MemcachedError,
+                PyErr_Format(PylibMCExc_MemcachedError,
                              "memcached_behavior_set returned %d", r);
                 goto error;
             }
@@ -657,20 +660,20 @@ error:
 
 /* }}} */
 
-static PyObject *HandMC_ErrFromMemcached(HandMC_Client *self, const char *what,
+static PyObject *PylibMC_ErrFromMemcached(PylibMC_Client *self, const char *what,
         memcached_return error) {
     if (error == MEMCACHED_ERRNO) {
-        PyErr_Format(HandMCExc_MemcachedError,
+        PyErr_Format(PylibMCExc_MemcachedError,
                 "system error %d from %s: %s", errno, what, strerror(errno));
     } else { 
-        PyErr_Format(HandMCExc_MemcachedError, "error %d from %s: %s",
+        PyErr_Format(PylibMCExc_MemcachedError, "error %d from %s: %s",
                 error, what, memcached_strerror(self->mc, error));
     }
     return NULL;
 }
 
 /* {{{ Pickling */
-static PyObject *_HandMC_GetPickles(const char *attname) {
+static PyObject *_PylibMC_GetPickles(const char *attname) {
     PyObject *pickle, *pickle_attr;
     
     pickle_attr = NULL;
@@ -689,12 +692,12 @@ static PyObject *_HandMC_GetPickles(const char *attname) {
     return pickle_attr;
 }
 
-static PyObject *_HandMC_Unpickle(const char *buff, size_t size) {
+static PyObject *_PylibMC_Unpickle(const char *buff, size_t size) {
     PyObject *pickle_load;
     PyObject *retval = NULL;
     
     retval = NULL;
-    pickle_load = _HandMC_GetPickles("loads");
+    pickle_load = _PylibMC_GetPickles("loads");
     if (pickle_load != NULL) {
         retval = PyObject_CallFunction(pickle_load, "s#", buff, size);
         Py_DECREF(pickle_load);
@@ -703,12 +706,12 @@ static PyObject *_HandMC_Unpickle(const char *buff, size_t size) {
     return retval;
 }
 
-static PyObject *_HandMC_Pickle(PyObject *val) {
+static PyObject *_PylibMC_Pickle(PyObject *val) {
     PyObject *pickle_dump;
     PyObject *retval = NULL;
 
     retval = NULL;
-    pickle_dump = _HandMC_GetPickles("dumps");
+    pickle_dump = _PylibMC_GetPickles("dumps");
     if (pickle_dump != NULL) {
         retval = PyObject_CallFunctionObjArgs(pickle_dump, val, NULL);
         Py_DECREF(pickle_dump);
@@ -718,33 +721,44 @@ static PyObject *_HandMC_Pickle(PyObject *val) {
 }
 /* }}} */
 
-static int _HandMC_CheckKey(PyObject *key) {
+static int _PylibMC_CheckKey(PyObject *key) {
     if (key == NULL) {
         PyErr_SetString(PyExc_ValueError, "key must be given");
+        return 0;
     } else if (!PyString_Check(key)) {
         PyErr_SetString(PyExc_TypeError, "key must be an instance of str");
-    } else if (PyString_GET_SIZE(key) > MEMCACHED_MAX_KEY) {
-        PyErr_Format(PyExc_ValueError, "key too long, max is %d",
-                MEMCACHED_MAX_KEY);
-    } /* TODO Check key contents here. */
+        return 0;
+    }
 
-    return PyErr_Occurred() ? 0 : 1;
+    return _PylibMC_CheckKeyStringAndSize(
+            PyString_AS_STRING(key), PyString_GET_SIZE(key));
 }
 
-static PyMethodDef HandMC_functions[] = {
+static int _PylibMC_CheckKeyStringAndSize(char *key, size_t size) {
+    if (size > MEMCACHED_MAX_KEY) {
+        PyErr_Format(PyExc_ValueError, "key too long, max is %d",
+                MEMCACHED_MAX_KEY);
+        return 0;
+    }
+    /* TODO Check key contents here. */
+
+    return 1;
+}
+
+static PyMethodDef PylibMC_functions[] = {
     {NULL}
 };
 
 PyMODINIT_FUNC init_pylibmc(void) {
     PyObject *module;
-    HandMC_Behavior *b;
+    PylibMC_Behavior *b;
     char name[128];
 
-    if (PyType_Ready(&HandMC_ClientType) < 0) {
+    if (PyType_Ready(&PylibMC_ClientType) < 0) {
         return;
     }
 
-    module = Py_InitModule3("_pylibmc", HandMC_functions,
+    module = Py_InitModule3("_pylibmc", PylibMC_functions,
             "Hand-made wrapper for libmemcached.\n\
 \n\
 You ought to look at python-memcached's documentation for now, seeing\n\
@@ -768,22 +782,22 @@ Oh, and: plankton.\n");
         return;
     }
 
-    HandMCExc_MemcachedError = PyErr_NewException(
+    PylibMCExc_MemcachedError = PyErr_NewException(
             "_pylibmc.MemcachedError", NULL, NULL);
 
-    Py_INCREF(&HandMC_ClientType);
-    PyModule_AddObject(module, "client", (PyObject *)&HandMC_ClientType);
+    Py_INCREF(&PylibMC_ClientType);
+    PyModule_AddObject(module, "client", (PyObject *)&PylibMC_ClientType);
 
-    PyModule_AddIntConstant(module, "server_type_tcp", HANDMC_SERVER_TCP);
-    PyModule_AddIntConstant(module, "server_type_udp", HANDMC_SERVER_UDP);
-    PyModule_AddIntConstant(module, "server_type_unix", HANDMC_SERVER_UNIX);
+    PyModule_AddIntConstant(module, "server_type_tcp", PYLIBMC_SERVER_TCP);
+    PyModule_AddIntConstant(module, "server_type_udp", PYLIBMC_SERVER_UDP);
+    PyModule_AddIntConstant(module, "server_type_unix", PYLIBMC_SERVER_UNIX);
 
     /* Add hasher and distribution constants. */
-    for (b = HandMC_hashers; b->name != NULL; b++) {
+    for (b = PylibMC_hashers; b->name != NULL; b++) {
         sprintf(name, "hash_%s", b->name);
         PyModule_AddIntConstant(module, name, b->flag);
     }
-    for (b = HandMC_distributions; b->name != NULL; b++) {
+    for (b = PylibMC_distributions; b->name != NULL; b++) {
         sprintf(name, "distribution_%s", b->name);
         PyModule_AddIntConstant(module, name, b->flag);
     }
