@@ -2,8 +2,6 @@
 
 Basic functionality.
 >>> c = _pylibmc.client([test_server])
->>> c.get_behaviors()
->>> c.set_behaviors(dict(hash=12))
 >>> c.set("test_key", 123)
 True
 >>> c.get("test_key")
@@ -67,6 +65,12 @@ True
 >>> sleep(3.1)
 >>> c.get("hi")
 >>>
+
+Now for keys with funny types.
+>>> c.set(1, "hi")
+True
+>>> c.get(1)
+'hi'
 """
 
 import _pylibmc
